@@ -231,8 +231,6 @@ void dasher_early_initialise()
 
 void dasher_late_initialise( int _width, int _height)
 {
-  const char *alphabet;
-
   dsc = new dasher_screen( _width, _height );
   interface->ChangeScreen( dsc );
 
@@ -305,6 +303,9 @@ void dasher_set_parameter_int( int_param p, long int value )
     case INT_LANGUAGEMODEL:
       interface->ChangeLanguageModel( value );
       break;
+    case INT_ONEBUTTON:
+      interface->SetOneButton( value );
+      break;
     case INT_VIEW:
       interface->ChangeView( value );
       break;
@@ -331,6 +332,8 @@ void dasher_set_parameter_int( int_param p, long int value )
     case INT_UNIFORM:
       interface->SetUniform(value);
       break;
+    default:
+      break;
     }
 }
 
@@ -402,6 +405,8 @@ void dasher_set_parameter_bool( bool_param p, bool value )
     case BOOL_PALETTECHANGE:
       interface->PaletteChange(value);
       break;
+    default:
+      break;
     }
 }
 
@@ -642,6 +647,16 @@ void dasher_pause( int x, int y )
   interface->PauseAt( x, y );
 }
 
+void dasher_reset_nats()
+{
+  interface->ResetNats();
+}
+
+double dasher_get_nats()
+{
+  return interface->GetNats();
+}
+
 // FIXME - this should not use c++ style strings
 
 string dasher_get_display_text( symbol Character )
@@ -659,6 +674,11 @@ int dasher_get_text_colour( symbol Character )
   return(interface->GetTextColour(Character));
 }
 
+int dasher_get_onebutton(void)
+{
+  return(interface->GetOneButton());
+}
+
 void dasher_resize_canvas( int _width, int _height )
 {
   delete( dsc );
